@@ -17,9 +17,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "fs/io/GunzipReader.hxx"
-#include "fs/io/FileReader.hxx"
-#include "fs/io/StdioOutputStream.hxx"
+#include "lib/zlib/GunzipReader.hxx"
+#include "io/FileReader.hxx"
+#include "io/StdioOutputStream.hxx"
 #include "fs/NarrowPath.hxx"
 #include "util/PrintException.hxx"
 
